@@ -21,9 +21,13 @@ class Constants(str, Enum):
 
 
 class CveRecordValidationError(Exception):
-    def __init__(self, message, errors):
-        super().__init__(message)
+    def __init__(self, *args, **kwargs):
+        errors = kwargs.pop("errors", None)
         self.errors = errors
+        super().__init__(*args, **kwargs)
+
+    def __reduce__(self):
+        return CveRecordValidationError, (self.args,)
 
 
 class CveRecord:
@@ -50,10 +54,11 @@ class CveRecord:
             schema = json.load(schema_file)
 
         validator = Draft7Validator(schema)
-        errors = [error.message for error in sorted(validator.iter_errors(cve_json), key=str)]
+        errors = sorted(validator.iter_errors(cve_json), key=lambda e: e.message)
         if errors:
+            errors_str = "\n".join(e.message for e in errors)
             raise CveRecordValidationError(
-                f"Schema validation against {schema_path} failed", errors
+                f"Schema validation against {schema_path} failed:\n{errors_str}", errors=errors
             )
 
 
