@@ -137,11 +137,16 @@ def test_cve_list():
             "CVE-2021-3002   PUBLISHED   acme         ann (acme)    Thu Jan 14 18:32:57 2021\n"
             "CVE-2021-3003   REJECTED    acme         eve (corp)    Thu Jan 14 18:34:50 2021\n"
         )
+        result = runner.invoke(cli, DEFAULT_OPTS + ["list", "--no-header"])
+        assert result.exit_code == 0, result.output
+        assert result.output == (
+            "CVE-2021-3001   RESERVED    acme   bob (acme)   Thu Jan 14 18:32:19 2021\n"
+            "CVE-2021-3002   PUBLISHED   acme   ann (acme)   Thu Jan 14 18:32:57 2021\n"
+            "CVE-2021-3003   REJECTED    acme   eve (corp)   Thu Jan 14 18:34:50 2021\n"
+        )
 
 
-@mock.patch("cvelib.cli.CveApi.publish")
-@mock.patch("cvelib.cli.CveApi.update_published")
-def test_cve_publish(update_published, publish):
+class TestCvePublish:
     cve_id = "CVE-2001-0635"
     cna_dict = {
         "affected": [
@@ -173,8 +178,7 @@ def test_cve_publish(update_published, publish):
             },
         ],
     }
-
-    cve_dict = {
+    cve_response_data = {
         "containers": {"cna": cna_dict},
         "cveMetadata": {
             "assignerOrgId": "19f229d4-f3d5-4605-bf93-521fa4499c06",
@@ -188,22 +192,56 @@ def test_cve_publish(update_published, publish):
         "dataType": "CVE_RECORD",
         "dataVersion": "5.0",
     }
-    cna_text = json.dumps(cna_dict)
-    response_dict = {"created": cve_dict, "message": f"{cve_id} record was successfully created."}
 
-    publish.return_value = response_dict
-    runner = CliRunner()
-    result = runner.invoke(cli, DEFAULT_OPTS + ["publish", cve_id, "--cve-json", cna_text])
-    assert result.exit_code == 0, result.output
-    assert result.output == (
-        "Published the following CVE:\n"
-        "\n"
-        f"{cve_id}\n"
-        "├─ State:\tPUBLISHED\n"
-        "├─ Owning CNA:\ttest_org\n"
-        "└─ Reserved on:\tTue Jun 29 12:33:52 2021\n"
-    )
-    assert not update_published.called
+    @mock.patch("cvelib.cli.CveApi.publish")
+    @mock.patch("cvelib.cli.CveApi.update_published")
+    def test_cve_publish(self, update_published, publish):
+        cna_text = json.dumps(self.cna_dict)
+        response_dict = {
+            "created": self.cve_response_data,
+            "message": f"{self.cve_id} record was " f"successfully created.",
+        }
+        publish.return_value = response_dict
+
+        runner = CliRunner()
+        result = runner.invoke(cli, DEFAULT_OPTS + ["publish", self.cve_id, "--cve-json", cna_text])
+        assert result.exit_code == 0, result.output
+        assert result.output == (
+            "Published the following CVE:\n"
+            "\n"
+            f"{self.cve_id}\n"
+            "├─ State:\tPUBLISHED\n"
+            "├─ Owning CNA:\ttest_org\n"
+            "└─ Reserved on:\tTue Jun 29 12:33:52 2021\n"
+        )
+        assert not update_published.called
+
+    @mock.patch("cvelib.cli.CveApi.publish")
+    @mock.patch("cvelib.cli.CveApi.update_published")
+    def test_cve_publish_from_file(self, update_published, publish, tmp_path):
+        with open(tmp_path / "cve.json", "w+") as cve_json_file:
+            cve_json_file.write(json.dumps(self.cna_dict))
+
+        response_dict = {
+            "created": self.cve_response_data,
+            "message": f"{self.cve_id} record was " f"successfully created.",
+        }
+        publish.return_value = response_dict
+
+        runner = CliRunner()
+        result = runner.invoke(
+            cli, DEFAULT_OPTS + ["publish", self.cve_id, "--cve-json-file", cve_json_file.name]
+        )
+        assert result.exit_code == 0, result.output
+        assert result.output == (
+            "Published the following CVE:\n"
+            "\n"
+            f"{self.cve_id}\n"
+            "├─ State:\tPUBLISHED\n"
+            "├─ Owning CNA:\ttest_org\n"
+            "└─ Reserved on:\tTue Jun 29 12:33:52 2021\n"
+        )
+        assert not update_published.called
 
 
 @mock.patch("cvelib.cli.CveApi.reject")
